@@ -411,13 +411,16 @@ class Model:
             for variable in self.variables:
                 if variable.row > sizetable[0]:
                     variable.row = variable.row + sizetable[1]
+            for style in self.styles:
+                if style.row > sizetable[0]:
+                    style.row = style.row + sizetable[1]
+        for sizetable in sizetables:
             for style in self.styles:
                 if style.row == sizetable[0]:
                     for n in range(sizetable[1]):
-                        self.__styles.append(Style(style.name,style.row+n,style.column,style.value))
-                elif style.row > sizetable[0]:
-                    style.row = style.row + sizetable[1]
-                style.rename()
+                        self.__styles.append(Style(style.name,style.row+n,style.column,style.data_type, style.font, style.alignment,style.fill, style.border))
+        for style in self.styles:
+            style.rename()
         return None
 
     def import_data(self, data):
